@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Macro.h 2296 2006-12-24 02:58:57Z svn $
+ * $Id: Macro.h 2332M 2007-01-06 18:08:21Z (ローカル) $
  *****************************************************************************/
 
 /**
@@ -49,7 +49,7 @@
 /**
  * メモリバリアです．
  */
-#ifndef WIN32
+#ifdef __GNUC__
 #define MEMORY_BARRIER __asm__ __volatile__ ("": : :"memory")
 #else
 #define MEMORY_BARRIER
@@ -306,7 +306,7 @@
  */
 #define ASSERT_EQUAL(a, b) do {                 \
         if ((a) != (b)) {                       \
-            DUMP_COND("qeual", a, b);           \
+            DUMP_COND("equal", a, b);           \
         }                                       \
     } while (0)
 #else
