@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostDataChecker.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: PostDataChecker.h 2326M 2007-01-06 17:50:27Z (ローカル) $
  *****************************************************************************/
 
 #ifndef POST_DATA_CHECKER_H
@@ -30,11 +30,10 @@
 
 #include "Environment.h"
 
-#include "apr.h"
+#include "apr_time.h"
 
 #include <cstdlib>
 
-#include "UploadItem.h"
 #include "Uncopyable.h"
 
 
