@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2291 2006-12-22 14:07:00Z svn $
+ * $Id: Auxiliary.cpp 2311 2006-12-24 21:27:56Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -49,7 +49,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2291 2006-12-22 14:07:00Z svn $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2311 2006-12-24 21:27:56Z svn $");
 
 void init_atomic(apr_pool_t *pool)
 {
@@ -177,19 +177,19 @@ apr_size_t atosize(const char *s)
 const char *get_file_ext(const char *file_name)
 {
     const char *file_ext;
-    apr_size_t file_name_length;
+    apr_size_t name_length;
 
-    file_name_length = strlen(file_name);
-    if (file_name_length == 0 ) {
+    name_length = strlen(file_name);
+    if (name_length == 0 ) {
         return "";
     }
 
-    for (file_ext = file_name+file_name_length-1; file_ext != file_name;
+    for (file_ext = file_name+name_length-1; file_ext != file_name;
          file_ext--) {
         if (*file_ext == '.') {
             return ++file_ext;
         }
-        if (!isalpha(static_cast<unsigned char>(*file_ext))) {
+        if (!isalnum(static_cast<unsigned char>(*file_ext))) {
             return "";
         }
     }
