@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.cpp 2313 2006-12-24 22:56:51Z svn $
+ * $Id: DownloadFlowController.cpp 2332 2006-12-31 02:07:19Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2313 2006-12-24 22:56:51Z svn $");
+SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2332 2006-12-31 02:07:19Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -84,6 +84,8 @@ void DownloadFlowController::remove_session(apr_sockaddr_t *sockaddr)
         THROW(MESSAGE_BUG_FOUND);
     }
 
+    // downloader が NULL ではない場合，downloader->session_count は 0
+    // より大きい
     downloader->session_count--;
 
     if (downloader_count_ == 0) {
@@ -153,7 +155,7 @@ bool DownloadFlowController::downloader_list_add(apr_sockaddr_t *sockaddr)
         }
     }
 
-    if (i == DLD_MAX_SESSION_COUNT) {
+    if (i == ARRAY_SIZE_OF(downloader_list_)) {
         THROW(MESSAGE_BUG_FOUND);
     }
 
