@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.cpp 2309 2006-12-24 10:48:50Z svn $
+ * $Id: PostFlowController.cpp 2313 2006-12-24 22:56:51Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -34,7 +34,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2309 2006-12-24 10:48:50Z svn $");
+SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2313 2006-12-24 22:56:51Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -47,7 +47,7 @@ PostFlowController::PostFlowController(apr_size_t min_post_interval_sec)
     (void)apr_atomic_set(&lock_, ReadWriteLocker::NOT_LOCKER);
 }
 
-bool PostFlowController::can_post(apr_sockaddr_t *ip_address)
+bool PostFlowController::can_post(apr_sockaddr_t *sockaddr)
 {
     apr_time_t time_limit;
 
@@ -58,14 +58,14 @@ bool PostFlowController::can_post(apr_sockaddr_t *ip_address)
 
     time_limit = apr_time_now() - min_post_interval_time_;
 
-    return poster_list_is_contain(ip_address, time_limit);
+    return poster_list_is_contain(sockaddr, time_limit);
 }
 
-void PostFlowController::regist_post(apr_sockaddr_t *ip_address)
+void PostFlowController::regist_post(apr_sockaddr_t *sockaddr)
 {
     WriteLocker lock(&lock_);
 
-    poster_list_add(ip_address);
+    poster_list_add(sockaddr);
 }
 
 PostFlowController *PostFlowController::get_instance(apr_shm_t *shm,
@@ -118,10 +118,8 @@ const char *PostFlowController::dump_list(apr_pool_t *pool,
 /******************************************************************************
  * private メソッド
  *****************************************************************************/
-void PostFlowController::poster_list_add(apr_sockaddr_t *ip_address)
+void PostFlowController::poster_list_add(apr_sockaddr_t *sockaddr)
 {
-    apr_size_t ip_address_size;
-
     poster_top_++;
     if (poster_top_ == ARRAY_SIZE_OF(poster_list_)) {
         poster_top_ = 0;
@@ -133,11 +131,8 @@ void PostFlowController::poster_list_add(apr_sockaddr_t *ip_address)
         }
     }
 
-    ip_address_size = get_address_size(ip_address);
-
-    poster_list_[poster_top_].ip_address_size = ip_address_size;
-    memcpy(&(poster_list_[poster_top_].ip_address), get_address(ip_address),
-           ip_address_size);
+    strncpy(poster_list_[poster_top_].paddress, get_paddress(sockaddr),
+            MAX_PADDRESS_SIZE - 1);
     poster_list_[poster_top_].time = apr_time_now();
 }
 
@@ -157,24 +152,24 @@ void PostFlowController::poster_list_clean()
     poster_tail_ = i;
 }
 
-bool PostFlowController::poster_list_is_contain(apr_sockaddr_t *ip_address,
+bool PostFlowController::poster_list_is_contain(apr_sockaddr_t *sockaddr,
                                                 apr_time_t time_limit) const
 {
+    const char *paddress;
     apr_size_t i;
 
     if (poster_top_ == poster_tail_) {
         return true;
     }
 
+    paddress = get_paddress(sockaddr);
+
     i = poster_top_;
     do {
         if (poster_list_[i].time < time_limit) {
             return true;
         }
-        if (is_address_match(&(poster_list_[i].ip_address[0]),
-                             poster_list_[i].ip_address_size,
-                             get_address(ip_address),
-                             get_address_size(ip_address))) {
+        if (is_address_match(poster_list_[i].paddress, paddress)) {
             return false;
         }
     } while ((i = (i == 0)
@@ -186,8 +181,8 @@ bool PostFlowController::poster_list_is_contain(apr_sockaddr_t *ip_address,
 
 const char *PostFlowController::dump_poster(apr_pool_t *pool, poster_t *poster)
 {
-    return apr_psprintf(pool, "%-24u : %" APR_TIME_T_FMT "\n",
-                        poster->ip_address[0], poster->time);
+    return apr_psprintf(pool, "%24s : %" APR_TIME_T_FMT "\n",
+                        &(poster->paddress[1]), poster->time);
 }
 
 
@@ -197,7 +192,7 @@ const char *PostFlowController::dump_poster(apr_pool_t *pool, poster_t *poster)
 #ifdef DEBUG_PostFlowController
 #include "TestRunner.h"
 
-apr_sockaddr_t DUMMY_IP_ADDRESS;
+const char DUMMY_ADDRESS[]              = "127.0.0.1";
 const apr_time_t MIN_POST_INTERVAL_SEC  = 1;
 const apr_size_t ATTACK_COUNT           = 100;
 
@@ -206,16 +201,17 @@ void show_usage(const char *prog_name)
     cerr << "Usage: " << prog_name << endl;
 }
 
-void run_can_post(PostFlowController *flow_controller)
+void run_can_post(PostFlowController *flow_controller,
+                  apr_sockaddr_t *sockaddr)
 {
     apr_size_t i;
 
     show_test_name("can_post");
 
-    flow_controller->regist_post(&DUMMY_IP_ADDRESS);
+    flow_controller->regist_post(sockaddr);
 
     for (i = 0; i < ATTACK_COUNT; i++) {
-        if (flow_controller->can_post(&DUMMY_IP_ADDRESS)) {
+        if (flow_controller->can_post(sockaddr)) {
             break;
         }
         apr_sleep(100000);
@@ -228,13 +224,18 @@ void run_can_post(PostFlowController *flow_controller)
 
 void run_all(apr_pool_t *pool, int argc, const char * const *argv)
 {
+    apr_sockaddr_t *sockaddr;
+
     if (argc != 1) {
         THROW(MESSAGE_ARGUMENT_INVALID);
     }
 
     PostFlowController flow_controller(MIN_POST_INTERVAL_SEC);
     show_line();
-    run_can_post(&flow_controller);
+
+    sockaddr = get_sockaddr(pool, DUMMY_ADDRESS);
+
+    run_can_post(&flow_controller, sockaddr);
 }
 
 #endif
