@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.cpp 2296 2006-12-24 02:58:57Z svn $
+ * $Id: UploadItemManager.cpp 2337 2007-01-06 17:42:09Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -47,7 +47,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2296 2006-12-24 02:58:57Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2337 2007-01-06 17:42:09Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -302,158 +302,12 @@ void UploadItemManager::create_item_id_index(apr_size_t *item_id,
     }
 
     header = item_list_->get_by_index(0);
-    while (*item_id < header->id) {
+    while (*item_id <= header->id) {
         (*item_id)++;
     }
     *item_index = header->index + 1;
 }
 
-
-/******************************************************************************
- * テスト
- *****************************************************************************/
-#ifdef DEBUG_UploadItemManager
-#include <string>
-
-#include "apr_shm.h"
-
-#include "UploadItemListReader.h"
-#include "CleanPointer.h"
-#include "Auxiliary.h"
-
-#include "TestRunner.h"
-
-// static const apr_size_t TARGET_ITEM_COUNT = 10;
-// static const apr_size_t RUN_ITER_COUNT      = 5000;
-
-void show_usage(const char *prog_name)
-{
-    cerr << "Usage: " << prog_name << " <DAT_DIR_PATH>" << endl;
-}
-
-// static void run_read_by_index(apr_pool_t *pool,
-//                               UploadItemManager *item_manager,
-//                               apr_size_t item_count,
-//                               apr_size_t *ids_sort_by_view,
-//                               apr_uint16_t *indexes_sort_by_view)
-// {
-//     volatile double start_time;
-//     volatile double end_time;
-//     BBSCommentIterator *bcomment_iter;
-
-//     APR_PALLOC(bcomment_iter, BBSCommentIterator *, pool,
-//                BBSCommentIterator::MEMORY_SIZE);
-
-//     start_time = get_usage_sec();
-//     for (apr_size_t i = 0; i < RUN_ITER_COUNT; i++) {
-//         for (apr_size_t j = 0; j < item_count; j++) {
-//             item_manager->get_item_by_index(pool,
-//                                                 indexes_sort_by_view[j],
-//                                                 ids_sort_by_view[j],
-//                                                 bcomment_iter);
-//             CleanPointer<BBSCommentIterator> clean_ptr(bcomment_iter);
-//         }
-//     }
-//     end_time = get_usage_sec();
-
-//     show_item("by index",
-//               (end_time - start_time) * 1000/RUN_ITER_COUNT/item_count,
-//               " msec");
-// }
-
-// static void run_read_by_id(apr_pool_t *pool, UploadItemManager *item_manager,
-//                            apr_size_t item_count,
-//                            apr_size_t *ids_sort_by_view)
-// {
-//     volatile double start_time;
-//     volatile double end_time;
-//     BBSCommentIterator *bcomment_iter;
-//     UploadItem::bbs_comment_p_t bcomment_p;
-//     apr_size_t total_message_size;
-
-//     APR_PALLOC(bcomment_iter, BBSCommentIterator *, pool,
-//                BBSCommentIterator::MEMORY_SIZE);
-
-//     total_message_size = 0;
-
-//     start_time = get_usage_sec();
-//     for (apr_size_t i = 0; i < RUN_ITER_COUNT; i++) {
-//         for (apr_size_t j = 0; j < item_count; j++) {
-//             item_manager->get_item_by_id(pool, ids_sort_by_view[j],
-//                                              bcomment_iter);
-
-//             bcomment_iter->get_comment(&bcomment_p);
-//             total_message_size += strlen(bcomment_p.message);
-
-//             CleanPointer<BBSCommentIterator> clean_ptr(bcomment_iter);
-//         }
-//     }
-//     end_time = get_usage_sec();
-
-//     show_item("by id",
-//               (end_time - start_time) * 1000/RUN_ITER_COUNT/item_count,
-//               " msec");
-// }
-
-// static void run_all_read(apr_pool_t *pool, UploadItemManager *item_manager)
-// {
-//     apr_uint16_t item_count;
-//     apr_size_t *ids_sort_by_view;
-//     apr_uint16_t *indexes_sort_by_view;
-
-//     show_test_name("read");
-
-//     item_count = TARGET_ITEM_COUNT;
-//     item_manager->get_item_info_sort_by_view(pool, &item_count,
-//                                                  &ids_sort_by_view,
-//                                                  &indexes_sort_by_view);
-
-//     run_read_by_index(pool, item_manager, item_count,
-//                       ids_sort_by_view, indexes_sort_by_view);
-//     run_read_by_id(pool, item_manager, item_count, ids_sort_by_view);
-// }
-
-void run_all(apr_pool_t *pool, int argc, const char * const *argv)
-{
-    const char *data_dir_path;
-    apr_shm_t *manager_shm;
-//     apr_shm_t *list_shm;
-
-    if (argc != 2) {
-        THROW(MESSAGE_ARGUMENT_INVALID);
-    }
-
-    data_dir_path = argv[1];
-
-    if (!is_exist(pool, data_dir_path)) {
-        THROW(MESSAGE_DATA_DIR_NOT_FOUND);
-    }
-
-    manager_shm = create_shm(pool, UploadItemManager::get_memory_size());
-//     list_shm = create_shm(pool, UploadItemList::get_memory_size());
-
-
-//     UploadItemManager *item_manager
-//         = UploadItemManager::get_instance(manager_shm, pool, data_dir_path);
-//     UploadItemList *item_list = UploadItemListReader::read(pool, data_dir_path,
-//                                                            list_shm);
-//     item_manager->init(item_list);
-
-//     show_item("data_dir", data_dir_path);
-//     show_item("manager memory",
-//               UploadItemManager::get_memory_size()/1024/static_cast<double>(1024),
-//               " MB");
-//     show_item("on memory thread", item_manager->get_item_count(), "");
-//     show_line();
-
-//     run_all_read(pool, item_manager);
-
-//     // チェック
-//     UploadItemManager::check_finalize_state(item_manager);
-}
-
-#endif
-
 // Local Variables:
 // mode: c++
 // coding: utf-8-dos
